@@ -14,18 +14,16 @@
 
 import torchvision
 
-from rikai.mixin import Pretrained
-from rikai.pytorch.models.torchvision import ObjectDetectionModelType
+from rikai.pytorch.models.torch import (
+    detection_label_fn,
+    ObjectDetectionModelType,
+)
 
-__all__ = ["MODEL_TYPE"]
+ssd = ObjectDetectionModelType(
+    "ssd", pretrained_fn=torchvision.models.detection.ssd.ssd300_vgg16
+)
 
-
-class SSDModelType(ObjectDetectionModelType, Pretrained):
-    def __init__(self):
-        super().__init__("SSD")
-
-    def pretrained_model(self):
-        return torchvision.models.detection.ssd.ssd300_vgg16(pretrained=True)
-
-
-MODEL_TYPE = SSDModelType()
+ssdlite = ObjectDetectionModelType(
+    "ssdlite",
+    pretrained_fn=torchvision.models.detection.ssdlite320_mobilenet_v3_large,
+)
