@@ -113,7 +113,7 @@ class PointType(UserDefinedType):
         return Point(datum[0], datum[1], datum[2])
 
     def simpleString(self) -> str:
-        return "PointType"
+        return "point"
 
 
 class Box3dType(UserDefinedType):
@@ -151,7 +151,7 @@ class Box3dType(UserDefinedType):
         return Box3d(datum[0], datum[1], datum[2], datum[3], datum[4])
 
     def simpleString(self) -> str:
-        return "Box3dType"
+        return "box3d"
 
 
 class MaskType(UserDefinedType):
@@ -162,8 +162,8 @@ class MaskType(UserDefinedType):
         return StructType(
             fields=[
                 StructField("type", ShortType(), False),
-                StructField("height", IntegerType(), True),
-                StructField("width", IntegerType(), True),
+                StructField("height", IntegerType(), False),
+                StructField("width", IntegerType(), False),
                 StructField(
                     "polygon",
                     ArrayType(ArrayType(FloatType(), False), False),
@@ -199,7 +199,7 @@ class MaskType(UserDefinedType):
         height = datum[1]
         width = datum[2]
         if mask_type == Mask.Type.POLYGON:
-            return Mask.from_polygon(datum[3])
+            return Mask.from_polygon(datum[3], height=height, width=width)
         elif mask_type == Mask.Type.RLE:
             return Mask.from_rle(datum[4], height=height, width=width)
         elif mask_type == Mask.Type.COCO_RLE:
@@ -208,4 +208,4 @@ class MaskType(UserDefinedType):
             raise ValueError(f"Unrecognized mask type: {datum[0]}")
 
     def simpleString(self) -> str:
-        return "Mask"
+        return "mask"
