@@ -19,7 +19,7 @@ from __future__ import annotations
 
 from enum import Enum
 from numbers import Real
-from typing import Optional, Sequence, Tuple, Union
+from typing import List, Optional, Sequence, Tuple, Union
 
 import numpy as np
 from PIL import Image, ImageDraw
@@ -294,8 +294,8 @@ class Box2d(ToNumpy, Sequence, ToDict, Drawable):
 
     @staticmethod
     def ious(
-        boxes1: Union[Sequence[Box2d], np.ndarray],
-        boxes2: Union[Sequence[Box2d], np.ndarray],
+        boxes1: Union[List[Box2d], np.ndarray],
+        boxes2: Union[List[Box2d], np.ndarray],
     ) -> Optional[np.ndarray]:
         """Compute intersection over union(IOU).
 
@@ -312,7 +312,7 @@ class Box2d(ToNumpy, Sequence, ToDict, Drawable):
             For two lists of box2ds, which have the length of N, and M respectively,
             this function should return a N*M matrix, each element is the iou value
             `(float,[0, 1])`.
-            Returns None if one of the input is empty.
+            Returns None if one of the inputs is empty.
 
         Example
         -------
@@ -333,16 +333,18 @@ class Box2d(ToNumpy, Sequence, ToDict, Drawable):
         >>> Box2d.ious(list1, list2)
         """  # noqa: E501
 
-        assert isinstance(boxes1, (Sequence, np.ndarray))
-        assert isinstance(boxes2, (Sequence, np.ndarray))
-
-        if not boxes1 or not boxes2:
-            return None
+        if not isinstance(boxes1, (list, np.ndarray)) or not isinstance(
+            boxes2, (list, np.ndarray)
+        ):
+            raise ValueError("Input must be a list/np.array fo box2d objects")
 
         if not isinstance(boxes1, np.ndarray):
             boxes1 = np.array(boxes1)
         if not isinstance(boxes2, np.ndarray):
             boxes2 = np.array(boxes2)
+        if np.size(boxes1) == 0 or np.size(boxes2) == 0:
+            return None
+
         row_count = boxes1.shape[0]
         area1 = Box2d._area(boxes1).reshape(row_count, -1)
         area2 = Box2d._area(boxes2)
@@ -359,11 +361,11 @@ class Box2d(ToNumpy, Sequence, ToDict, Drawable):
         return iou_mat
 
     def iou(
-        self, other: Union[Box2d, Sequence[Box2d], np.ndarray]
+        self, other: Union[Box2d, List[Box2d], np.ndarray]
     ) -> Union[float, np.ndarray]:
         """Compute intersection over union(IOU)."""
         assert isinstance(
-            other, (Box2d, Sequence, np.ndarray)
+            other, (Box2d, list, np.ndarray)
         ), f"Can only compute iou between Box2d, got {type(other)}"
         if isinstance(other, Box2d):
             other_arr = np.array([other])
@@ -474,10 +476,10 @@ class Mask(ToNumpy, ToDict, Drawable):
     ----------
     data: list or :py:class:`np.ndarray`
         The mask data. Can be a numpy array or a list.
-    height: int, optional
-        The height of the image this mask applies to.
     width: int, optional
         The width of the image this mask applies to.
+    height: int, optional
+        The height of the image this mask applies to.
     mask_type: :py:class:`Mask.Type`
         The type of the mask.
 
@@ -495,14 +497,14 @@ class Mask(ToNumpy, ToDict, Drawable):
         if ann["iscrowed"] == 0:
             mask = Mask.from_polygon(
                 ann["segmentation"],
-                height=image["height"],
                 width=image["width],
+                height=image["height"],
             )
         else:
             mask = Mask.from_coco_rle(
                 ann["segmentation"]["counts"],
-                height=image["height"],
                 width=image["width],
+                height=image["height"],
             )
 
     """
@@ -519,8 +521,8 @@ class Mask(ToNumpy, ToDict, Drawable):
     def __init__(
         self,
         data: Union[list, np.ndarray],
-        height: Optional[int] = None,
         width: Optional[int] = None,
+        height: Optional[int] = None,
         mask_type: Mask.Type = Type.POLYGON,
     ):
         if mask_type != Mask.Type.POLYGON and (
@@ -531,27 +533,27 @@ class Mask(ToNumpy, ToDict, Drawable):
         self.type = mask_type
         self.data = data
 
-        self.height = height
         self.width = width
+        self.height = height
 
     @staticmethod
-    def from_rle(data: list[int], height: int, width: int) -> Mask:
+    def from_rle(data: list[int], width: int, height: int) -> Mask:
         """Convert a (row-based) RLE mask (segmentation) into Mask
 
         Parameters
         ----------
         data: list[int]
             the RLE data
-        height: int
-            The height of the image which the mask applies to.
         width: int
             The width of the image which the mask applies to.
+        height: int
+            The height of the image which the mask applies to.
         """
 
-        return Mask(data, height=height, width=width, mask_type=Mask.Type.RLE)
+        return Mask(data, width=width, height=height, mask_type=Mask.Type.RLE)
 
     @staticmethod
-    def from_coco_rle(data: list[int], height: int, width: int) -> Mask:
+    def from_coco_rle(data: list[int], width: int, height: int) -> Mask:
         """Convert a COCO RLE mask (segmentation) into Mask
 
         Parameters
@@ -564,11 +566,11 @@ class Mask(ToNumpy, ToDict, Drawable):
             The width of the image which the mask applies to.
         """
         return Mask(
-            data, height=height, width=width, mask_type=Mask.Type.COCO_RLE
+            data, width=width, height=height, mask_type=Mask.Type.COCO_RLE
         )
 
     @staticmethod
-    def from_polygon(data: list[list[float]], height: int, width: int) -> Mask:
+    def from_polygon(data: list[list[float]], width: int, height: int) -> Mask:
         """Build mask from a Polygon
 
         Parameters
@@ -576,13 +578,13 @@ class Mask(ToNumpy, ToDict, Drawable):
         data: list[list[float]]
             Multiple Polygon segmentation data. i.e.,
             ``[[x0, y0, x1, y1, ...], [x0, y0, x1, y1, ...]])``
-        height: int
-            The height of the image which the mask applies to.
         width: int
             The width of the image which the mask applies to.
+        height: int
+            The height of the image which the mask applies to.
         """
         return Mask(
-            data, height=height, width=width, mask_type=Mask.Type.POLYGON
+            data, width=width, height=height, mask_type=Mask.Type.POLYGON
         )
 
     @staticmethod
